@@ -16,6 +16,7 @@ from scipy.optimize import minimize
 from ..permittivity_models import firn_permittivity
 from ..ImpdarError import ImpdarError
 
+
 def reverse(self):
     """Reverse radar data
 
@@ -138,7 +139,7 @@ def nmo(self, ant_sep, uice=1.69e8, uair=3.0e8, const_firn_offset=None, rho_prof
         else:
             # get RMS velocity used for correction
             d = minimize(optimize_moveout_depth,.5*t*uice,args=(t,ant_sep,d_interp,u_interp),
-                         tol=1e-8,bounds=((0,0.5*t*uair),))['x'][0]
+                         tol=1e-8,bounds=((0, 0.5*t*uair),))['x'][0]
             u_rms = np.sqrt(np.mean(u_interp[d_interp<d]**2.))
         # get the upper leg of the trave_path triangle (direct arrival) from the antenna separation and the rms velocity
         tsep_ice = 1e6*(ant_sep / u_rms)
@@ -300,17 +301,18 @@ def crop(self, lim, top_or_bottom='top', dimension='snum', uice=1.69e8, rezero=T
         if rezero:
             self.travel_time = self.travel_time - self.travel_time[0]
         self.snum = self.data.shape[0]
+        mintrig = 0
     else:
         # pretrig, vector input
         # Need to figure out if we need to do any shifting
         # The extra shift compared to the smallest
-        mintrig = np.min(ind)
+        mintrig = np.nanmin(ind)
         lims = [mintrig, self.data.shape[0]]
-        self.trig = self.trig-ind
-        trig_ends = self.data.shape[0] - (ind - mintrig) - 1
+        self.trig = self.trig - ind
         data_old = self.data.copy()
         self.data = np.zeros((data_old.shape[0] - mintrig, data_old.shape[1]))
         self.data[:, :] = np.nan
+        trig_ends = self.data.shape[0] - (ind - mintrig)
         for i in range(self.data.shape[1]):
             self.data[:trig_ends[i], i] = data_old[ind[i]:, i]
         self.travel_time = self.travel_time[lims[0]:lims[1]]
@@ -318,6 +320,10 @@ def crop(self, lim, top_or_bottom='top', dimension='snum', uice=1.69e8, rezero=T
             self.travel_time = self.travel_time - self.travel_time[0]
         self.snum = self.data.shape[0]
 
+    if top_or_bottom == 'top':
+        if self.picks is not None:
+            self.picks.crop(ind)
+
     try:
         self.flags.crop[0] = 1
         self.flags.crop[2] = self.flags.crop[1] + lims[1]
@@ -437,6 +443,10 @@ def restack(self, traces):
     self.data = stack
     self.trace_num = np.arange(self.tnum).astype(int) + 1
     self.trace_int = trace_int
+
+    if hasattr(self, 'picks') and self.picks is not None:
+        self.picks.restack(traces)
+
     for var, val in oned_newdata.items():
         setattr(self, var, val)
     self.flags.restack = True
@@ -540,13 +550,21 @@ def constant_space(self, spacing, min_movement=1.0e-2, show_nomove=False):
     else:
         self.data = interp1d(temp_dist, self.data[:, good_vals])(new_dists)
 
-    for attr in ['lat', 'long', 'elev', 'x_coord', 'y_coord', 'decday', 'pressure', 'trig']:
+    for attr in ['lat', 'long', 'x_coord', 'y_coord', 'decday', 'pressure', 'trig']:
         setattr(self,
                 attr,
                 interp1d(temp_dist, getattr(self, attr)[good_vals])(new_dists))
+    for attr in ['elev']:
+        if getattr(self, attr) is not None:
+            setattr(self,
+                    attr,
+                    interp1d(temp_dist, getattr(self, attr)[good_vals])(new_dists))
 
     if self.picks is not None:
-        for attr in ['samp1', 'samp2', 'samp3', 'power', 'time']:
+        for attr in ['samp1', 'samp2', 'samp3']:
+            if getattr(self.picks, attr) is not None:
+                setattr(self.picks, attr, np.round(interp1d(temp_dist, getattr(self.picks, attr)[:, good_vals])(new_dists)))
+        for attr in ['power', 'time']:
             if getattr(self.picks, attr) is not None:
                 setattr(self.picks, attr, interp1d(temp_dist, getattr(self.picks, attr)[:, good_vals])(new_dists))
 
@@ -600,9 +618,13 @@ def elev_correct(self, v_avg=1.69e8):
     self.data = np.zeros((data_old.shape[0] + max_samp, data_old.shape[1]))
     self.data[:, :] = np.nan
 
+    top_inds = (elev_diffs / dz_avg).astype(int)
     for i in range(self.data.shape[1]):
-        left_ind = int(elev_diffs[i] // dz_avg)
-        self.data[left_ind: left_ind + data_old.shape[0], i] = data_old[:, i]
+        top_ind = top_inds[i]
+        self.data[top_ind: top_ind + data_old.shape[0], i] = data_old[:, i]
+
+    if hasattr(self, 'picks') and self.picks is not None:
+        self.picks.crop(-top_inds)
 
     self.elevation = np.hstack((np.arange(np.max(self.elev), np.min(self.elev), -dz_avg),
                                 np.min(self.elev) - self.nmo_depth))
